package example.cmp.ejbql;

import javax.servlet.*;
import javax.servlet.http.*;

import javax.naming.*;
import javax.ejb.*;

import java.util.*;

import java.io.PrintWriter;

/**
 * A client to illustrate entity bean finder methods
 */
public class FindServlet extends HttpServlet {
  private CourseHome courseHome = null;
  private TeacherHome teacherHome = null;
  private StudentHome studentHome = null;
  private HouseHome houseHome = null;

  public void init()
    throws ServletException
  {
    try {
      // The JNDI context containing EJBs
      Context ejb = (Context) new InitialContext().lookup("java:comp/env/cmp");

      // get the bean stubs
      courseHome = (CourseHome) ejb.lookup("ejbql_course");
      teacherHome = (TeacherHome) ejb.lookup("ejbql_teacher");
      studentHome = (StudentHome) ejb.lookup("ejbql_student");
      houseHome= (HouseHome) ejb.lookup("ejbql_house");

    } catch (NamingException e) {
      throw new ServletException(e);
    }
  }

  public void service(HttpServletRequest req, HttpServletResponse res)
    throws java.io.IOException, ServletException
  {
    PrintWriter out = res.getWriter();
    res.setContentType("text/html");

    try {
      out.println("<H3>Students enrolled at Hogwarts</H3>");
      Collection allStudents = studentHome.findAll();
      Iterator studentIter = allStudents.iterator();
      
      while (studentIter.hasNext()) {
        out.println(((Student)studentIter.next()).getName() + "<BR>");
      }

      // Find out for all Students who their teachers are
      out.println("<h3>Students are taking classes from these teachers:</h3>");
      studentIter = allStudents.iterator();
      
      while (studentIter.hasNext()) {
        Student student = (Student)studentIter.next();
        String studentName = student.getName();
        Iterator teacherIter =
          teacherHome.findByStudent(studentName).iterator();
        out.println("<b>"+studentName+"'s teachers</b><BR>");
        
        if (! teacherIter.hasNext())
          out.println(studentName + " is not taking any classes<BR>");
        
        while (teacherIter.hasNext())
          out.println(((Teacher)teacherIter.next()).getName()+"<BR>");

        out.println("<BR>");
      }
      
      // Find out what classes are taken by Students in Gryffindor
      String houseName = "Gryffindor";
      out.println("<h3>Students in " + houseName +
                  " are taking these classes:</h3>");
      Collection courses = courseHome.findByHouse("Gryffindor");
      Iterator courseIter = courses.iterator();
      
      if (! courseIter.hasNext())
        out.println("Students in " + houseName + " are lazy. " +
                    "Nobody is taking any courses.<BR>");
      
      while (courseIter.hasNext()) {
        Course course = (Course)courseIter.next();
        out.println(course.getName() + " (taught by Professor " +
                    course.getTeacher().getName() + ")<BR>");
      }
      
      out.println("<BR>");
    } catch (FinderException e) {
      throw new ServletException(e);
    }
  }
}
