package example.cmp.relations.one2many;

/**
 * Implementation of the StudentBean.  Each instance of StudentBean
 * maps to a table entry of "one2many_students", where student is defined.
 *
 * </p>StudentBean is abstract since it's taking advantage of container-managed
 * persistence.  Resin-CMP will create the implementation of the abstract
 * methods.
 *
 * <p/>StudentBean also takes advantage of the AbstractEntityBean
 * implementation.  AbstractEntityBean is just a stub
 * EntityBean implementation with default methods to make life
 * a little more sane for simple beans.
 */
abstract public class StudentBean extends com.caucho.ejb.AbstractEntityBean {
  /**
   * Returns the student name.  The name is the primary key.
   */
  abstract public String getName();
  /**
   * Returns the house the student belongs to. This method needs to exist
   * because the field <code>house</code> is defined as a CMR field.
   */
  abstract public House getHouse();
  /**
   * Sets the student's house. This method needs to exist
   * because the field <code>house</code> is defined as a CMR field.
   */
  abstract public void setHouse(House house);
}
