package example.cmp.single_table;

import javax.ejb.*;

/**
 * The client's view of the house table.  Home interfaces define methods
 * to find entries in the table and to create new table entries.
 *
 * <p>All home interfaces define the <code>findByPrimaryKey</code> method,
 * letting clients find items in the table.  Other find methods are allowed.
 * An example for an application-defined find method is
 * in <a href="../find/package-summary.html">example.cmp.find</a>.
 *
 * <p>Clients normally use JNDI to get the <code>HouseHome</code> object
 * and then store it for all further requests.  The <code>init()</code>
 * method of <code>HouseServlet</code> gives an example of getting the
 * home interface.
 *
 * <p>All local home interfaces extend EJBLocalHome.
 */
public interface HouseHome extends EJBLocalHome {
  /**
   * Returns the house specified by the primary key.  Every home
   * interface must define a findByPrimaryKey method.  The single
   * argument is the primary key and the return value is the
   * local interface.
   *
   * @param name the house name, i.e. the primary key.
   *
   * @return the matching house
   *
   * @exception FinderException if the database lookup fails.
   */
  House findByPrimaryKey(String name) throws FinderException;
}
